@@ -18,20 +18,16 @@ Version 0.0102
 
 =cut
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 
 __PACKAGE__->mk_accessors(qw(
     alternate_interpreters
 ));
 
-sub _get_simple_params
+sub _get_private_simple_params
 {
     my $self = shift;
-    return 
-    [
-        qw(alternate_interpreters), 
-        @{$self->NEXT::_get_simple_params()}
-    ];
+    return [qw(alternate_interpreters)];
 }
 
 =head1 SYNOPSIS
